@@ -11,8 +11,8 @@ import os
 import re
 import sys
 
-from typing import Any, Callable
-from collections.abc import Iterable
+from collections.abc import Callable, Iterable
+from typing import Any
 
 import pytest
 
